@@ -266,8 +266,33 @@ int compare(const void *a, const void *b) {
 	return(*((double*)a)>*((double*)b));
 }
 
+
+// Public domain code from http://www.johndcook.com/cpp_erf.html
+double myerfc(double x)
+{
+    // constants
+    double a1 =  0.254829592;
+    double a2 = -0.284496736;
+    double a3 =  1.421413741;
+    double a4 = -1.453152027;
+    double a5 =  1.061405429;
+    double p  =  0.3275911;
+
+    // Save the sign of x
+    int sign = 1;
+    if (x < 0)
+        sign = -1;
+    x = fabs(x);
+
+    // A&S formula 7.1.26
+    double t = 1.0/(1.0 + p*x);
+    double y = 1.0 - (((((a5*t + a4)*t) + a3)*t + a2)*t + a1)*t*exp(-x*x);
+
+    return(1-sign*y);
+}
+
 double Phi(double x) {
-	return(.5*erfc(-x/sqrt(2.)));
+	return(.5*myerfc(-x/sqrt(2.)));
 }
 
 double Probit(double p) {
